@@ -606,11 +606,10 @@ class Document < AbstractBlock
     when :refs
       @catalog[:refs][value[0]] ||= (ref = value[1])
       ref
-    #when :footnotes, :indexterms
     when :footnotes
       @catalog[type] << value
     else
-      @catalog[type] << (type == :images ? (ImageReference.new value[0], value[1]) : value) if @options[:catalog_assets]
+      @catalog[type] << (type == :images ? (ImageReference.new value, @attributes['imagesdir']) : value) if @options[:catalog_assets]
     end
   end
 
